DecodeIterError

Enum DecodeIterError 

pub enum DecodeIterError {
    Eof,
    NeedMore,
    Malformed(ContextError),
}
Boundary error type surfaced by Decoder::next

These will all be coerced into the loop stopping. The decoder must be fed more bytes before the loop can continue

Variants



Eof

The buffer is empty and no more bytes are available



NeedMore

The packet is not done decoding yet - incompete



Malformed(ContextError)

The bytes present in the buffer could not be parsed as the target type. The Decoder has already advanced past the offending bytes (drained the framed packet, or the consumed prefix in resume mode) to guarantee forward progress on subsequent calls